embassy-stm32

Crates

git

Versions

stm32h745ii-cm4

Flavors

TransferOptions

Struct TransferOptions 

#[non_exhaustive]
pub struct TransferOptions {
Show 13 fields pub pburst: Burst, pub mburst: Burst, pub flow_ctrl: FlowControl, pub fifo_threshold: Option<FifoThreshold>, pub priority: Priority, pub circular: bool, pub half_transfer_ir: bool, pub complete_transfer_ir: bool, pub packing: Packing, pub buffer_size: u8, pub byte_swap: bool, pub half_word_swap: bool, pub word_swap: bool,
}
DMA transfer options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
pburst: Burst

Peripheral burst transfer configuration

mburst: Burst

Memory burst transfer configuration

flow_ctrl: FlowControl

Flow control configuration

fifo_threshold: Option<FifoThreshold>

FIFO threshold for DMA FIFO mode. If none, direct mode is used.

priority: Priority

Request priority level

circular: bool

Enable circular DMA

Note: If you enable circular mode manually, you may want to build and .await the Transfer in a separate task. Since DMA in circular mode need manually stop, .await in current task would block the task forever.

half_transfer_ir: bool

Enable half transfer interrupt

complete_transfer_ir: bool

Enable transfer complete interrupt

packing: Packing

DMA packing configuration

If Packing::ZeroExtendOrLeftTruncate, psize may be adjusted based on the platform to acheive no packing.

buffer_size: u8

Max bytes to transfer at once, 1-64

byte_swap: bool

Swap bytes in each half-word

half_word_swap: bool

Swap half-words in each word

word_swap: bool

Swap words in each double-word